@@ -18,8 +18,8 @@ class ConsolidationType(str, Enum):
 class ConsolidateParameters(FormatterParameters):
     type: ConsolidationType = Field(ConsolidationType.unknown, description="""Type of consolidation, use<br />
     - *linker* to retain only known entities<br />
-    - *unkown* to retain all but prepending `unknown_` to the label name of unknwon entities<br />
-    - *unkown_only* to retain only unknown entities prepending `unknown_` to their label name""")
+    - *unknown* to retain all but prepending `unknown_` to the label name of unknwon entities<br />
+    - *unknown_only* to retain only unknown entities prepending `unknown_` to their label name""")
 
 
 class ConsolidateFormatter(FormatterBase):
